@@ -6,7 +6,7 @@
 #ifndef _IP_VS_H
 #define _IP_VS_H
 
-#define IP_VS_VERSION_CODE            0x000206
+#define IP_VS_VERSION_CODE            0x000207
 #define NVERSION(version)                       \
         (version >> 16) & 0xFF,                 \
         (version >> 8) & 0xFF,                  \
@@ -242,11 +242,11 @@ struct ip_vs_seq {
 struct ip_vs_stats
 {
         spinlock_t              lock;           /* spin lock */
-        unsigned long           conns;          /* connections scheduled */
-        unsigned long           inpkts;         /* incoming packets */
-        unsigned long           outpkts;        /* outgoing packets */
-        unsigned long           inbytes;        /* incoming bytes */
-        unsigned long           outbytes;       /* outgoing bytes */
+        __u32                   conns;          /* connections scheduled */
+        __u32                   inpkts;         /* incoming packets */
+        __u32                   outpkts;        /* outgoing packets */
+        __u64                   inbytes;        /* incoming bytes */
+        __u64                   outbytes;       /* outgoing bytes */
 };
 
 
@@ -297,7 +297,7 @@ struct ip_vs_service {
 	__u16			protocol; /* which protocol (TCP/UDP) */
 	__u32			addr;	  /* IP address for virtual service */
 	__u16			port;	  /* port number for the service */
-	unsigned long		fwmark;   /* firewall mark of the service */
+	__u32                   fwmark;   /* firewall mark of the service */
 	unsigned		flags;	  /* service status flags */
 	unsigned		timeout;  /* persistent timeout in ticks */
 	__u32			netmask;  /* grouping granularity */
@@ -337,7 +337,7 @@ struct ip_vs_dest {
         __u16			protocol; /* which protocol (TCP/UDP) */
 	__u32			vaddr;	  /* IP address for virtual service */
 	__u16			vport;	  /* port number for the service */
-	unsigned long		vfwmark;  /* firewall mark of the service */
+	__u32                   vfwmark;  /* firewall mark of the service */
 };
 
 
@@ -539,7 +539,10 @@ extern struct ip_vs_scheduler *ip_vs_lookup_scheduler(const char *sched_name);
 extern int sysctl_use_dst;
 extern int sysctl_ip_vs_cache_bypass;
 extern atomic_t ip_vs_dropentry;
-extern struct ip_vs_service *ip_vs_service_get(unsigned long fwmark,
+extern struct ip_vs_stats ip_vs_stats;
+extern rwlock_t __ip_vs_svc_lock;
+
+extern struct ip_vs_service *ip_vs_service_get(__u32 fwmark,
                                                __u16 protocol,
                                                __u32 vaddr, __u16 vport);
 static inline void ip_vs_service_put(struct ip_vs_service *svc)
