@@ -1,7 +1,7 @@
 /*
  * IPVS         Application module
  *
- * Version:     $Id: ip_vs_app.c,v 1.8 2001/03/18 15:01:45 wensong Exp $
+ * Version:     $Id: ip_vs_app.c,v 1.9 2001/03/22 12:57:46 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -144,7 +144,7 @@ static struct ip_vs_app * ip_vs_app_get(unsigned short proto, __u16 port)
                 /*
                  * Test and MOD_INC_USE_COUNT atomically
                  */
-                if (!try_inc_mod_count(vapp->module)) {
+                if (vapp->module && !try_inc_mod_count(vapp->module)) {
                         /*
                          * This application module is just deleted
                          */
@@ -155,7 +155,8 @@ static struct ip_vs_app * ip_vs_app_get(unsigned short proto, __u16 port)
                         return vapp;
                 }
                 
-                __MOD_DEC_USE_COUNT(vapp->module);
+                if (vapp->module)
+                        __MOD_DEC_USE_COUNT(vapp->module);
         }
 
         read_unlock_bh(&__ip_vs_app_lock);
@@ -215,7 +216,8 @@ int ip_vs_unbind_app(struct ip_vs_conn *cp)
                         vapp->done_conn(vapp, cp);
                 cp->app = NULL;
                 /*  atomic_dec(&vapp->refcnt); */
-                __MOD_DEC_USE_COUNT(vapp->module);
+                if (vapp->module)
+                        __MOD_DEC_USE_COUNT(vapp->module);
         }
         return (vapp != NULL);
 }
@@ -435,16 +437,14 @@ static int ip_vs_app_getinfo(char *buffer, char **start, off_t offset,
                         pos += 64;
                         if (pos <= offset)
                                 continue;
-                        if (pos > offset+length) {
-                                pos -= 64;
-                                goto done;
-                        }
                         sprintf(temp, "%-3s  %-7u %-6d %-17s",
                                 ip_vs_proto_name(IP_VS_APP_PROTO(vapp->type)),
                                 IP_VS_APP_PORT(vapp->type),
-                                GET_USE_COUNT(vapp->module),
+                                vapp->module?GET_USE_COUNT(vapp->module):0,
                                 vapp->name);
                         len += sprintf(buffer+len, "%-63s\n", temp);
+                        if (pos >= offset+length)
+                                goto done;
                 }
         }
   done:
