@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_conn.c,v 1.12 2001/03/18 15:01:45 wensong Exp $
+ * Version:     $Id: ip_vs_conn.c,v 1.13 2001/03/22 12:57:46 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -1323,9 +1323,9 @@ ip_vs_conn_getinfo(char *buffer, char **start, off_t offset, int length)
 	struct ip_vs_conn *cp;
 	struct list_head *l, *e;
 
-        pos = 70;
+        pos = 128;
         if (pos > offset) {
-                len += sprintf(buffer+len, "%-69s\n",
+                len += sprintf(buffer+len, "%-127s\n",
                                "Pro FromIP   FPrt ToIP     TPrt DestIP   DPrt State       Expires");
         }
 
@@ -1339,15 +1339,9 @@ ip_vs_conn_getinfo(char *buffer, char **start, off_t offset, int length)
                 l = &ip_vs_table[idx];
                 for (e=l->next; e!=l; e=e->next) {
                         cp = list_entry(e, struct ip_vs_conn, c_list);
-                        pos += 70;
+                        pos += 128;
                         if (pos <= offset)
                                 continue;
-                        if (pos > offset+length) {
-                                pos -= 70;
-                                ct_read_unlock_bh(idx);
-                                goto done;
-                        }
-
                         sprintf(temp,
                                 "%-3s %08X %04X %08X %04X %08X %04X %-11s %7lu",
                                 ip_vs_proto_name(cp->protocol),
@@ -1356,7 +1350,11 @@ ip_vs_conn_getinfo(char *buffer, char **start, off_t offset, int length)
                                 ntohl(cp->daddr), ntohs(cp->dport),
                                 ip_vs_state_name(cp->state),
                                 cp->timer.expires-jiffies);
-                        len += sprintf(buffer+len, "%-69s\n", temp);
+                        len += sprintf(buffer+len, "%-127s\n", temp);
+                        if (pos >= offset+length) {
+                                ct_read_unlock_bh(idx);
+                                goto done;
+                        }
                 }
                 ct_read_unlock_bh(idx);
 	}
