@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_core.c,v 1.15 2001/03/18 15:01:45 wensong Exp $
+ * Version:     $Id: ip_vs_core.c,v 1.16 2001/03/22 12:57:46 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -132,8 +132,6 @@ const char *ip_vs_proto_name(unsigned proto)
         }
 }
 
-extern struct ip_vs_stats ip_vs_stats;
-extern rwlock_t __ip_vs_svc_lock;
 
 static inline void
 ip_vs_in_stats(struct ip_vs_conn *cp, struct sk_buff *skb)
@@ -1156,7 +1154,6 @@ static unsigned int ip_vs_in(unsigned int hooknum,
             && (h.th->syn || (iph->protocol!=IPPROTO_TCP))
             && (svc = ip_vs_service_get(skb->nfmark, iph->protocol,
                                         iph->daddr, h.portp[1]))) {
-                
 		if (ip_vs_todrop()) {
 			/*
 			 * It seems that we are very loaded.
