@@ -2,7 +2,7 @@
  *      ipvsadm - IP Virtual Server ADMinistration program
  *                for IPVS NetFilter Module in kernel 2.4
  *
- *      Version: $Id: ipvsadm.c,v 1.8 2001/03/18 15:01:46 wensong Exp $
+ *      Version: $Id: ipvsadm.c,v 1.9 2001/03/22 12:57:46 wensong Exp $
  *
  *      Authors: Wensong Zhang <wensong@linuxvirtualserver.org>
  *               Peter Kese <peter.kese@ijs.si>
@@ -97,6 +97,7 @@
 #include <sys/socket.h>
 #include <sys/types.h>
 #include <sys/param.h>
+#include <sys/wait.h>           /* For waitpid */
 #include <arpa/inet.h>
 
 #include <asm/types.h>          /* For __uXX types */
@@ -145,7 +146,7 @@
 #define SERVICE_ADDR    0x1
 #define SERVICE_PORT    0x2
 
-#define VS_PROC_FILE    "/proc/net/ip_vs"
+#define IPVS_PROC_FILE    "/proc/net/ip_vs"
 #define CONN_PROC_FILE  "/proc/net/ip_vs_conn"
 
 int string_to_number(const char *s, int min, int max);
@@ -178,19 +179,19 @@ int str_is_digit(const char *str);
 
 int main(int argc, char **argv)
 {
+	/*
+	 *      Warn the user if the IPVS version is out of date
+	 */
+	check_ipvs_version();
+
         /*
-         *      If no other arguement, list VS_PROC_FILE
+         *      If no other arguement, list IPVS_PROC_FILE
          */
         if (argc == 1){
                 list_vs(FMT_NONE);
 		exit(0);
 	}
         
-	/*
-	 *      Warn the user if the IPVS version is out of date
-	 */
-	check_ipvs_version();
-
         /*
          *	Process command line arguments
          */
@@ -560,14 +561,14 @@ int parse_options(int argc, char **argv, int reading_stdin,
 			dynamic_array_destroy(a, DESTROY_STR);
 		}
 		poptFreeContext(context);
-		return(result);
+		exit(result);
 	}
 
         if (write_stdout) {
                 *format |= FMT_RULE;
                 list_vs(*format);
 		poptFreeContext(context);
-                return 0;
+                exit(0);
         }
         
 	/* 
@@ -1111,7 +1112,8 @@ int parse_timeout(char *buf, unsigned *timeout)
 }
 
 
-void usage_exit(const char *program, const int exit_status) {
+void usage_exit(const char *program, const int exit_status)
+{
         FILE *stream;
 
         if (exit_status != 0)
@@ -1181,7 +1183,8 @@ void usage_exit(const char *program, const int exit_status) {
 }
 
 
-void version_exit(const int exit_status) {
+void version_exit(const int exit_status)
+{
         FILE *stream;
 
         if (exit_status != 0)
@@ -1195,7 +1198,8 @@ void version_exit(const int exit_status) {
 }
 
 
-void version(FILE *stream){
+void version(FILE *stream)
+{
         fprintf(stream,
                 "ipvsadm " IPVSADM_VERSION " (compiled with "
                 IPVS_OPTION_PROCESSING " and IPVS v%d.%d.%d)\n",
@@ -1203,12 +1207,35 @@ void version(FILE *stream){
 }
 
 
-void fail(int err, char *text) {
+void fail(int err, char *text)
+{
         printf("%s\n",text);
         exit(err);
 }
 
 
+int modprobe_ipvs(void)
+{
+    char *argv[] = { "/sbin/modprobe", "-s", "-k", "--", "ip_vs", NULL };
+    int child;
+    int status;
+    int rc;
+
+    if (!(child = fork())) {
+	    execv(argv[0], argv);
+	    exit(1);
+    }
+
+    rc = waitpid(child, &status, 0);
+
+    if (!WIFEXITED(status) || WEXITSTATUS(status)) {
+	    return 1;
+    }
+
+    return 0;
+}
+
+
 void check_ipvs_version(void)
 {
         static char buffer[128];
@@ -1217,12 +1244,17 @@ void check_ipvs_version(void)
 	int patch;
         FILE *handle;
 
-        handle = fopen(VS_PROC_FILE, "r");
+        handle = fopen(IPVS_PROC_FILE, "r");
         if (!handle) {
-                fprintf(stderr, "Could not open the %s file\n"
-                        "Are you sure that IP Virtual Server is supported "
-                        "by the kernel?\n", VS_PROC_FILE);
-                exit(1);
+                /* try to request the ip_vs module */
+                if (modprobe_ipvs()
+                    || !(handle = fopen(IPVS_PROC_FILE, "r"))) {
+                        fprintf(stderr, "Could not open the %s file\n"
+                                "Are you sure that IP Virtual Server is "
+                                "built in the kernel or as module?\n",
+                                IPVS_PROC_FILE);
+                        exit(1);
+                }
         }
 
         /*
@@ -1345,11 +1377,11 @@ void list_vs(unsigned int format)
         FILE *handle;
         int i;
 
-        handle = fopen(VS_PROC_FILE, "r");
+        handle = fopen(IPVS_PROC_FILE, "r");
         if (!handle) {
                 fprintf(stderr, "Could not open the %s file\n"
                         "Are you sure that IP Virtual Server is supported "
-                        "by the kernel?\n", VS_PROC_FILE);
+                        "by the kernel?\n", IPVS_PROC_FILE);
                 exit(1);
         }
 
